@@ -2,17 +2,13 @@ from pathlib import Path
 
 import click
 
-from todotree.Config import Config
-from todotree.Taskmanager import Taskmanager
+from todotree.Commands.AbstractCommand import AbstractCommand
 
 
-class Cd:
-    def __init__(self, config: Config, task_manager: Taskmanager):
-        self.taskManager = task_manager
-        self.config = config
+class Cd(AbstractCommand):
 
     def run(self):
-        config_path: Path = Path(self.config.todo_folder)
+        config_path: Path = Path(self.config.paths.todo_folder)
         self.config.console.verbose("The location to the data folder is: ")
 
         if config_path.is_absolute():
@@ -24,3 +20,6 @@ class Cd:
         full_path: Path = base_path / config_path
         click.echo(str(full_path))
         exit()
+
+    def __call__(self, *args, **kwargs):
+        raise NotImplemented
\ No newline at end of file
